<!-- SPDX-License-Identifier: CC-BY-4.0 -->
<!-- Copyright Contributors to the Egeria project. -->

# Operational

These widgets display different kinds of information useful to monitor the status of different elements of an Egeria deployment.
Widgets will continue to be added over time to cover more facets of catalog use.

* get_eng_action_status.py - lists assets containing the user provided search string in the display name or qualified name. Search string must be a minimum of three characters.
* get_tech_type_elements.py - shows a tree view for the details of a supported technology type.
* get_tech_type_template.py - shows a tree view of the template associated with a supported technology type.
* view_coco_status.py - provides a tree view of a collection with all nested collections and items within the collection.
* view_eng_action_status.py - provides a live view of the status of engine actions.
* view_gov_eng_status.py - provides a live view of a governance engine status.
* view_integ_daemeon_status.py - provides a live view of an integration daemon status.
* view_platform_status.py - provides a live status view of the known servers on known platforms.
* view_server_list.py - provides a more detailed live status view of the servers on a single platform.
* view_server_status.py - provides a minimal live status view of the servers on a single platform.
* view_asset_changes.py - experiment in progress
* view_asset_events.py - experiment in progress

----
License: [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/),
Copyright Contributors to the Egeria project.